@@ -33,11 +33,11 @@ DBUS_BEGIN_DECLS
 
 #if 1
 #define DBUS_HAVE_INT64 1
-_DBUS_GNUC_EXTENSION typedef long long dbus_int64_t;
-_DBUS_GNUC_EXTENSION typedef unsigned long long dbus_uint64_t;
+_DBUS_GNUC_EXTENSION typedef long dbus_int64_t;
+_DBUS_GNUC_EXTENSION typedef unsigned long dbus_uint64_t;
 
-#define DBUS_INT64_CONSTANT(val)  (_DBUS_GNUC_EXTENSION (val##LL))
-#define DBUS_UINT64_CONSTANT(val) (_DBUS_GNUC_EXTENSION (val##ULL))
+#define DBUS_INT64_CONSTANT(val)  (_DBUS_GNUC_EXTENSION (val##L))
+#define DBUS_UINT64_CONSTANT(val) (_DBUS_GNUC_EXTENSION (val##UL))
 
 #else
 #undef DBUS_HAVE_INT64
@@ -56,11 +56,11 @@ typedef unsigned short dbus_uint16_t;
  */
 #define DBUS_MAJOR_VERSION 1
 #define DBUS_MINOR_VERSION 6
-#define DBUS_MICRO_VERSION 2
+#define DBUS_MICRO_VERSION 8
 
-#define DBUS_VERSION_STRING "1.6.2"
+#define DBUS_VERSION_STRING "1.6.8"
 
-#define DBUS_VERSION ((1 << 16) | (6 << 8) | (2)) 
+#define DBUS_VERSION ((1 << 16) | (6 << 8) | (8)) 
 
 DBUS_END_DECLS
 
